@@ -12,7 +12,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.54';
+$VERSION = '1.55';
 
 my %coordConv = (
     ValueConv    => 'Image::ExifTool::GPS::ToDegrees($val)',
@@ -369,7 +369,7 @@ my %coordConv = (
         },
         WriteAlso => {
             'GPS:GPSLatitude' => '$val',
-            'GPS:GPSLatitudeRef' => '$val < 0 ? "S" : "N"',
+            'GPS:GPSLatitudeRef' => '(defined $val and $val < 0) ? "S" : "N"',
         },
         ValueConv => '$val[1] =~ /^S/i ? -$val[0] : $val[0]',
         PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
@@ -386,7 +386,7 @@ my %coordConv = (
         },
         WriteAlso => {
             'GPS:GPSLongitude' => '$val',
-            'GPS:GPSLongitudeRef' => '$val < 0 ? "W" : "E"',
+            'GPS:GPSLongitudeRef' => '(defined $val and $val < 0) ? "W" : "E"',
         },
         Require => {
             0 => 'GPS:GPSLongitude',
@@ -407,12 +407,18 @@ my %coordConv = (
         # Require either GPS:GPSAltitudeRef or XMP:GPSAltitudeRef
         RawConv => '(defined $val[1] or defined $val[3]) ? $val : undef',
         ValueConv => q{
-            my $alt = $val[0];
-            $alt = $val[2] unless defined $alt;
-            return undef unless defined $alt and IsFloat($alt);
-            return(($val[1] || $val[3]) ? -$alt : $alt);
+            foreach (0,2) {
+                next unless defined $val[$_] and IsFloat($val[$_]) and defined $val[$_+1];
+                return $val[$_+1] ? -abs($val[$_]) : $val[$_];
+            }
+            return undef;
         },
         PrintConv => q{
+            foreach (0,2) {
+                next unless defined $val[$_] and IsFloat($val[$_]);
+                next unless defined $prt[$_+1] and $prt[$_+1] =~ /Sea/;
+                return((int($val[$_]*10)/10) . ' m ' . $prt[$_+1]);
+            }
             $val = int($val * 10) / 10;
             return(($val =~ s/^-// ? "$val m Below" : "$val m Above") . " Sea Level");
         },
@@ -476,13 +482,13 @@ sub PrintTimeStamp($)
 #------------------------------------------------------------------------------
 # Convert degrees to DMS, or whatever the current settings are
 # Inputs: 0) ExifTool reference, 1) Value in degrees,
-#         2) format code (0=no format, 1=CoordFormat, 2=XMP format)
+#         2) format code (0=no format, 1=CoordFormat, 2=XMP format, 3=signed unformatted)
 #         3) 'N' or 'E' if sign is significant and N/S/E/W should be added
 # Returns: DMS string
 sub ToDMS($$;$$)
 {
     my ($et, $val, $doPrintConv, $ref) = @_;
-    my ($fmt, @fmt, $num, $sign, $rtnVal);
+    my ($fmt, @fmt, $num, $sign, $rtnVal, $neg);
 
     unless (length $val) {
         # don't convert an empty value
@@ -499,6 +505,10 @@ sub ToDMS($$;$$)
         }
         $ref = " $ref" unless $doPrintConv and $doPrintConv eq '2';
     } else {
+        if ($doPrintConv and $doPrintConv eq '3') {
+            $neg = 1 if $val < 0;
+            $doPrintConv = 0;
+        }
         $val = abs($val);
         $ref = '';
     }
@@ -548,6 +558,7 @@ sub ToDMS($$;$$)
         # trim trailing zeros in XMP
         $rtnVal =~ s/(\d)0+$ref$/$1$ref/ if $doPrintConv eq '2';
     } else {
+        $neg and map { $_ *= -1 } @c;
         $rtnVal = "@c$ref";
     }
     return $rtnVal;
@@ -599,7 +610,7 @@ GPS (Global Positioning System) meta information in EXIF data.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
