@@ -21,7 +21,7 @@ sub ProcessKodakPatch($$$);
 sub WriteUnknownOrPreview($$$);
 sub FixLeicaBase($$;$);
 
-$VERSION = '2.10';
+$VERSION = '2.12';
 
 my $debug;          # set to 1 to enable debugging code
 
@@ -89,6 +89,11 @@ my $debug;          # set to 1 to enable debugging code
             FixBase => 1, # necessary for AVI and MOV videos
         },
     },
+    {
+        Name => 'MakerNoteDJIInfo',
+        Condition => '$$valPt =~ /^\[ae_dbg_info:/',
+        SubDirectory => { TagTable => 'Image::ExifTool::DJI::Info' },
+    },
     {
         Name => 'MakerNoteDJI',
         Condition => '$$self{Make} eq "DJI" and $$valPt !~ /^...\@AMBA/s',
@@ -570,6 +575,17 @@ my $debug;          # set to 1 to enable debugging code
             ByteOrder => 'Unknown',
         },
     },
+    {
+        Name => 'MakerNoteOlympus3',
+        # new Olympus maker notes start with "OLYMPUS\0"
+        Condition => '$$valPt =~ /^OM SYSTEM\0/',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Olympus::Main',
+            Start => '$valuePtr + 16',
+            Base => '$start - 16',
+            ByteOrder => 'Unknown',
+        },
+    },
     {
         Name => 'MakerNoteLeica',
         # (starts with "LEICA\0\0\0")
@@ -1593,6 +1609,8 @@ IFD_TRY: for ($offset=$firstTry; $offset<=$lastTry; $offset+=2) {
                 }
                 # patch for Sony cameras like the DSC-P10 that have invalid MakerNote entries
                 next if $num == 12 and $$et{Make} eq 'SONY' and $index >= 8;
+                # patch for Apple ProRaw DNG which uses format 16 in the maker notes
+                next if $format == 16 and $$et{Make} eq 'Apple';
                 # (would like to verify tag ID, but some manufactures don't
                 #  sort entries in order of tag ID so we don't have much of
                 #  a handle to verify this field)
@@ -1812,7 +1830,7 @@ maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
